CrudApi class

Core CRUD operations API.

Provides methods for creating, reading, updating, and deleting contacts.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Contact contact, {Account? account}) → Future<String>
createAll(List<Contact> contacts, {Account? account}) → Future<List<String>>
delete(String id) → Future<void>
deleteAll(List<String> ids) → Future<void>
get(String id, {Set<ContactProperty>? properties, Account? account, bool androidLookup = false}) → Future<Contact?>
getAll({Set<ContactProperty>? properties, ContactFilter? filter, Account? account, int? limit}) → Future<List<Contact>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(Contact contact) → Future<void>
updateAll(List<Contact> contacts) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

instance → const CrudApi