GroupsApi class

Group management API.

Handles operations for contact groups (e.g., "Family", "Work", "Friends").

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addContacts({required String groupId, required List<String> contactIds}) → Future<void>
Adds contacts to a group.
create(String name, {Account? account}) → Future<Group>
Creates a new contact group.
delete(String groupId) → Future<void>
Deletes a group.
get(String groupId, {bool withContactCount = false}) → Future<Group?>
Gets a single group by ID.
getAll({List<Account>? accounts, bool withContactCount = false}) → Future<List<Group>>
Gets all contact groups.
getOf(String contactId) → Future<List<Group>>
Gets all groups that contain the specified contact.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeContacts({required String groupId, required List<String> contactIds}) → Future<void>
Removes contacts from a group.
toString() → String
A string representation of this object.
inherited
update(Group group) → Future<void>
Updates a group.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

instance → const GroupsApi