ProfileApi class

User Profile / "Me" Card API.

Fetches the user's own profile:

  • macOS: Returns the "Me" card.
  • Android: Returns the device owner's profile.

Returns null if no profile is set on the device. Not available on iOS.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get({Set<ContactProperty>? properties}) → Future<Contact?>
Fetches the user's own profile.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

instance → const ProfileApi