id property
Account identifier.
On iOS/macOS, this is the container identifier. On Android, this is always an empty string since Android accounts don't have stable IDs.
Implementation
final String id;
Account identifier.
On iOS/macOS, this is the container identifier. On Android, this is always an empty string since Android accounts don't have stable IDs.
final String id;