AndroidData class

Android-specific data (Android only).

Contains all Android-only fields for a contact.

Constructors

AndroidData({bool? isFavorite, String? customRingtone, bool? sendToVoicemail, int? lastUpdatedTimestamp, AndroidIdentifiers? identifiers, Map? debugData})
const

Properties

customRingtone → String?
URI for custom ringtone.
final
debugData → Map?
All data mimetypes for debugging.
final
hashCode → int
The hash code for this object.
no setteroverride
identifiers → AndroidIdentifiers?
Contact identifiers (lookup key, raw contact ID, etc.).
final
isFavorite → bool?
Whether contact is starred/favorited.
final
isNotEmpty → bool
Returns true if this AndroidData object has any data.
no setter
lastUpdatedTimestamp → int?
Last update timestamp in milliseconds since epoch.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendToVoicemail → bool?
Whether to send calls to voicemail.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map? json) → AndroidData?