ContactChange class
A single contact change.
This represents one change to a single contact. If multiple contacts change, multiple ContactChange objects will be emitted, one per contact.
Constructors
- ContactChange({required ContactChangeType type, required String contactId})
-
const
Properties
- contactId → String
-
The ID of the contact that changed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ContactChangeType
-
The type of change that occurred.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited