EventLabel enum

Event label types (e.g., birthdays, anniversaries).

Label Android iOS
anniversary ✔ ✔
birthday ✔ ✔
other ✔ ✔
custom ✔ ✔

iOS limits birthdays to one per contact; Android allows multiple events of any type.

Inheritance
Available extensions

Values

anniversary → const EventLabel
birthday → const EventLabel
other → const EventLabel
custom → const EventLabel

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isSupported → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<EventLabel>
A constant List of the values in this enum, in order of their declaration.