WebsiteLabel enum

Website URL label types.

Label Android iOS
blog ✔ ⨯
ftp ✔ ⨯
home ✔ ✔
homepage ✔ ✔
profile ✔ ⨯
school ⨯ ✔
work ✔ ✔
other ✔ ✔
custom ✔ ✔
Inheritance
Available extensions

Values

blog → const WebsiteLabel
ftp → const WebsiteLabel
home → const WebsiteLabel
homepage → const WebsiteLabel
profile → const WebsiteLabel
school → const WebsiteLabel
work → const WebsiteLabel
other → const WebsiteLabel
custom → const WebsiteLabel

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isSupported → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<WebsiteLabel>
A constant List of the values in this enum, in order of their declaration.