PermissionStatus enum

Detailed permission status for contacts access.

Permission states:

Note: Denying permission once leads to permanentlyDenied on iOS but denied on Android. Denying twice leads to permanentlyDenied on Android.

Inheritance
Available extensions

Values

granted → const PermissionStatus

Permission is fully granted.

limited → const PermissionStatus

Permission is granted with limited access (iOS 18+ only).

On iOS, this means the user has selected specific contacts to share.

denied → const PermissionStatus

Permission was denied by the user, but can still be requested again.

permanentlyDenied → const PermissionStatus

Permission was permanently denied (Android: "Don't ask again").

User must grant permission through system settings.

restricted → const PermissionStatus

Permission is restricted by system policy (e.g., parental controls).

notDetermined → const PermissionStatus

Permission has not been requested yet.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PermissionStatus>
A constant List of the values in this enum, in order of their declaration.