Email class

Email address property.

Constructors

Email({required String address, bool? isPrimary, Label<EmailLabel>? label, PropertyMetadata? metadata})
const

Properties

address → String
Email address.
final
hashCode → int
The hash code for this object.
no setteroverride
isPrimary → bool?
Whether this is the primary email address (Android only).
final
label → Label<EmailLabel>
Email label type.
final
metadata → PropertyMetadata?
Property identity metadata (used internally for updates).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? address, bool? isPrimary, Label<EmailLabel>? label, PropertyMetadata? metadata}) → Email
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map json) → Email