Name class

Structured name property.

Contact.displayName is computed automatically from these components by the platform after saving.

Android allows multiple names per contact; iOS allows only one. This plugin only supports one name per contact for simplicity.

Field Android iOS
first ✔ ✔
middle ✔ ✔
last ✔ ✔
prefix ✔ ✔
suffix ✔ ✔
phoneticFirst ✔ ✔
phoneticMiddle ✔ ✔
phoneticLast ✔ ✔
previousFamilyName ⨯ ✔
nickname ✔ ✔

Constructors

Name({String? first, String? middle, String? last, String? prefix, String? suffix, String? phoneticFirst, String? phoneticMiddle, String? phoneticLast, String? previousFamilyName, String? nickname, PropertyMetadata? metadata})
const

Properties

first → String?
First name.
final
hashCode → int
The hash code for this object.
no setteroverride
last → String?
Last name.
final
metadata → PropertyMetadata?
Property identity metadata (used internally for updates).
final
middle → String?
Middle name.
final
nickname → String?
Nickname.
final
phoneticFirst → String?
Phonetic first name.
final
phoneticLast → String?
Phonetic last name.
final
phoneticMiddle → String?
Phonetic middle name.
final
prefix → String?
Name prefix.
final
previousFamilyName → String?
Previous family name (iOS only, e.g., maiden name).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → String?
Name suffix.
final

Methods

copyWith({String? first, String? middle, String? last, String? prefix, String? suffix, String? phoneticFirst, String? phoneticMiddle, String? phoneticLast, String? previousFamilyName, String? nickname, PropertyMetadata? metadata}) → Name
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map json) → Name