Organization class

Organization property.

Android allows multiple organizations per contact; iOS/macOS allows only one.

Field Android iOS
name ✔ ✔
jobTitle ✔ ✔
departmentName ✔ ✔
phoneticName ✔ ✔
jobDescription ✔ ⨯
symbol ✔ ⨯
officeLocation ✔ ⨯

Constructors

Organization({String? name, String? jobTitle, String? departmentName, String? phoneticName, String? jobDescription, String? symbol, String? officeLocation})
const

Properties

departmentName → String?
Department name.
final
hashCode → int
The hash code for this object.
no setteroverride
jobDescription → String?
Job description (Android only).
final
jobTitle → String?
Job title.
final
name → String?
Company or organization name.
final
officeLocation → String?
Office location (Android only).
final
phoneticName → String?
Phonetic company name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol → String?
Company symbol or ticker (Android only).
final

Methods

copyWith({String? name, String? jobTitle, String? departmentName, String? phoneticName, String? jobDescription, String? symbol, String? officeLocation}) → Organization
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map json) → Organization