Phone class

Phone number property.

Constructors

Phone({required String number, String? normalizedNumber, bool? isPrimary, Label<PhoneLabel>? label, PropertyMetadata? metadata})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isPrimary → bool?
Whether this is the primary phone number (Android only).
final
label → Label<PhoneLabel>
Phone label type.
final
metadata → PropertyMetadata?
Property identity metadata (used internally for updates).
final
normalizedNumber → String?
Normalized phone number in E.164 format (Android only).
final
number → String
Phone number.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? number, String? normalizedNumber, bool? isPrimary, Label<PhoneLabel>? label, PropertyMetadata? metadata}) → Phone
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map json) → Phone