Photo class

Contact photo property.

Both thumbnail and full-size photos are optional and independent.

Constructors

Photo({Uint8List? thumbnail, Uint8List? fullSize})
const

Properties

fullSize → Uint8List?
High-resolution photo (full-size, original resolution from device).
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → Uint8List?
Small, low-resolution photo (thumbnail, typically 96x96 or 150x150 pixels).
final

Methods

copyWith({Uint8List? thumbnail, Uint8List? fullSize}) → Photo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map json) → Photo