Relation class

Relationship property.

Constructors

Relation({required String name, Label<RelationLabel>? label, PropertyMetadata? metadata})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
label → Label<RelationLabel>
Relationship label type.
final
metadata → PropertyMetadata?
Property identity metadata (used internally for updates).
final
name → String
Name of the related person.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, Label<RelationLabel>? label, PropertyMetadata? metadata}) → Relation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map json) → Relation