SocialMedia class

Social media profile property.

Constructors

SocialMedia({required String username, Label<SocialMediaLabel>? label, PropertyMetadata? metadata})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
label Label<SocialMediaLabel>
Social media label type.
final
metadata PropertyMetadata?
Property identity metadata (used internally for updates).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
Social media username.
final

Methods

copyWith({String? username, Label<SocialMediaLabel>? label, PropertyMetadata? metadata}) SocialMedia
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map json) SocialMedia