Website class

Website URL property.

Constructors

Website({required String url, Label<WebsiteLabel>? label, PropertyMetadata? metadata})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
label → Label<WebsiteLabel>
Website label type.
final
metadata → PropertyMetadata?
Property identity metadata (used internally for updates).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
Website URL.
final

Methods

copyWith({String? url, Label<WebsiteLabel>? label, PropertyMetadata? metadata}) → Website
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map json) → Website